__version__ = '0.1.1'

class base:
  def add(a, b):
    """Returns the sum of A+B"""
    return a + b

  def Subtract(a, b):
    """Returns the sum of A-B"""
    return a - b

  def Multiply(a, b):
    """Returns the sum of A*B"""
    return a * b

  def Divide(a, b):
    """Returns the sum of A/B"""
    return a/b